==> apache-druid-25.0.0-src.tar.gz: apache-druid-25.0.0-src/web-console/src/views/workbench-view/execution-details-pane/execution-details-pane.spec.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { shallow } from 'enzyme';
import React from 'react';

import { EXECUTION_INGEST_ERROR } from '../../../druid-models/execution/execution-ingest-error.mock';

import { ExecutionDetailsPane } from './execution-details-pane';

describe('ExecutionDetailsPane', () => {
  it('matches snapshot no init tab', () => {
    const comp = shallow(
      <ExecutionDetailsPane execution={EXECUTION_INGEST_ERROR} goToIngestion={() => {}} />,
    );

    expect(comp).toMatchSnapshot();
  });

  it('matches snapshot with init tab', () => {
    const comp = shallow(
      <ExecutionDetailsPane
        execution={EXECUTION_INGEST_ERROR}
        initTab="warnings"
        goToIngestion={() => {}}
      />,
    );

    expect(comp).toMatchSnapshot();
  });
});

==> apache-druid-31.0.2-src.tar.gz: apache-druid-31.0.2-src/web-console/src/views/workbench-view/execution-details-pane/execution-details-pane.spec.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React from 'react';

import { EXECUTION_INGEST_ERROR } from '../../../druid-models/execution/execution-ingest-error.mock';
import { shallow } from '../../../utils/shallow-renderer';

import { ExecutionDetailsPane } from './execution-details-pane';

describe('ExecutionDetailsPane', () => {
  it('matches snapshot no init tab', () => {
    const comp = shallow(
      <ExecutionDetailsPane execution={EXECUTION_INGEST_ERROR} goToTask={() => {}} />,
    );

    expect(comp).toMatchSnapshot();
  });

  it('matches snapshot with init tab', () => {
    const comp = shallow(
      <ExecutionDetailsPane
        execution={EXECUTION_INGEST_ERROR}
        initTab="warnings"
        goToTask={() => {}}
      />,
    );

    expect(comp).toMatchSnapshot();
  });
});
